SignatureErrorEvent

Struct SignatureErrorEvent 

pub struct SignatureErrorEvent {
    pub request_id: [u8; 32],
    pub responder: Pubkey,
    pub error: String,
}
Emitted when signature generation fails via chain_signatures::respond_error.

Warning: Debugging Only

This event is solely for debugging purposes. Do not use in production or rely upon for any business logic.

Event Type

Regular event (emitted via emit!)

Security Warning

Any address can emit this event. Error events are not cryptographically verified and should never be trusted for business logic decisions.

Fields

request_id: [u8; 32]

Request identifier of the failed request.

responder: Pubkey

Address of the MPC responder. Error events are not cryptographically verified.

error: String

Human-readable error description.